@@ -16,7 +16,7 @@
 # under the License.
 
 package Search::Elasticsearch::Role::Cxn;
-$Search::Elasticsearch::Role::Cxn::VERSION = '7.715';
+$Search::Elasticsearch::Role::Cxn::VERSION = '7.717';
 use Moo::Role;
 use Search::Elasticsearch::Util qw(parse_params throw to_list);
 use List::Util qw(min);
@@ -81,6 +81,13 @@ sub get_user_agent {
     return sprintf("elasticsearch-perl/%s (%s; perl %s)", $Search::Elasticsearch::VERSION, $^O, $]);
 }
 
+#===================================
+sub get_meta_header {
+#===================================
+    return sprintf("es=%s,pl=%s", $Search::Elasticsearch::VERSION, $^V);
+}
+
+
 #===================================
 sub BUILDARGS {
 #===================================
@@ -138,6 +145,16 @@ sub BUILDARGS {
 
     $default_headers{'User-Agent'} = $class->get_user_agent();
 
+    # Add Elastic meta header
+    $default_headers{'x-elastic-client-meta'} = $class->get_meta_header();
+
+    # Compatibility header
+    if (defined $ENV{ELASTIC_CLIENT_APIVERSIONING} &&
+        (lc($ENV{ELASTIC_CLIENT_APIVERSIONING}) eq 'true' || $ENV{ELASTIC_CLIENT_APIVERSIONING} eq '1')) {
+            $default_headers{'Accept'} = 'application/vnd.elasticsearch+json;compatible-with=7';
+            $default_headers{'Content-Type'} = 'application/vnd.elasticsearch+json; compatible-with=7';
+    }
+
     $params->{scheme}   = $scheme;
     $params->{is_https} = $scheme eq 'https';
     $params->{host}     = $host;
@@ -446,7 +463,7 @@ Search::Elasticsearch::Role::Cxn - Provides common functionality to HTTP Cxn imp
 
 =head1 VERSION
 
-version 7.715
+version 7.717
 
 =head1 DESCRIPTION
 
@@ -814,7 +831,7 @@ Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Elasticsearch BV.
+This software is Copyright (c) 2022 by Elasticsearch BV.
 
 This is free software, licensed under:
 
